==> mx-welcome_18.12.07.tar.xz: mx-welcome-18.12.07/translations/mx-welcome_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>You must run this program as normal user.</source>
        <translation>U moet dit programma als normale gebruiker uitvoeren.</translation>
    </message>
</context>
<context>
    <name>mxwelcome</name>
    <message>
        <location filename="../mxwelcome.ui" line="14"/>
        <location filename="../mxwelcome.cpp" line="54"/>
        <location filename="../mxwelcome.cpp" line="99"/>
        <location filename="../mxwelcome.cpp" line="111"/>
        <source>MX Welcome</source>
        <translation>MX Welkom</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="70"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Welcome to MX Linux, a fast, friendly, and stable OS loaded with amazing tools and supported by a great community. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Welkom bij MX Linux, een snelle, vriendelijke en stabiele OS die vol zit met verbazingwekkende gereedschappen en ondersteund wordt door een geweldige gemeenschap.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="512"/>
        <source>Codecs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="576"/>
        <source>Users Manual</source>
        <translation>Gebruikershandleiding</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="203"/>
        <source>Forums</source>
        <translation>Forums</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="280"/>
        <source>Videos</source>
        <translation>Video&apos;s</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="544"/>
        <source>Wiki</source>
        <translation>Wiki</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="486"/>
        <source>Tools</source>
        <translation>Gereedschap</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="377"/>
        <source>Contribute</source>
        <translation>Bijdragen</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="422"/>
        <source>Tweak (Panel, etc...)</source>
        <translation>Tweak (Paneel, etc...)</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="113"/>
        <source>Popular Apps</source>
        <translation>Populaire Apps</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:14pt; font-weight:600;&quot;&gt;MX-17 &amp;quot;Horizon&amp;quot;&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:14pt; font-weight:600;&quot;&gt;MX-17 &amp;quot;Horizon&amp;quot;&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Login Info</source>
        <translation type="vanished">Login Informatie</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="608"/>
        <source>FAQ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="641"/>
        <source>Show this dialog at start up</source>
        <translation>Laat deze dialoog bij het opstarten zien</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="706"/>
        <source>About this application</source>
        <translation>Over deze toepassing</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="709"/>
        <source>About...</source>
        <translation>Over...</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="716"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="770"/>
        <source>Quit application</source>
        <translation>Verlaat de applicatie</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="773"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="780"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="98"/>
        <source>About MX Welcome</source>
        <translation>Over MX Welkom</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="99"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="100"/>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation>Programma om een welkomstscherm te laten zien in MX Linux</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="102"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="103"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="104"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="105"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="121"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
    <message>
        <source>Live Login Info</source>
        <translation type="vanished">Live Login Informatie</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="57"/>
        <source>Default username:  &lt;b&gt;demo&lt;/b&gt; &lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Default demo password:  &lt;b&gt;demo&lt;/b&gt;</source>
        <translation>Standaard gebruikersnaam:  &lt;b&gt;demo&lt;/b&gt; &lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Standaard demo wachtwoord:  &lt;b&gt;demo&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="58"/>
        <source>&lt;b&gt;Root&lt;/b&gt; Password:  &lt;b&gt;root&lt;/b&gt;&lt;/p&gt; </source>
        <translation>&lt;b&gt;Root&lt;/b&gt; Wachtwoord:  &lt;b&gt;root&lt;/b&gt;&lt;/p&gt; </translation>
    </message>
</context>
</TS>

==> mx-welcome_19.1.tar.xz: mx-welcome-19.1/translations/mx-welcome_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>You must run this program as normal user.</source>
        <translation>U moet dit programma als normale gebruiker uitvoeren.</translation>
    </message>
</context>
<context>
    <name>mxwelcome</name>
    <message>
        <location filename="../mxwelcome.ui" line="14"/>
        <location filename="../mxwelcome.cpp" line="54"/>
        <location filename="../mxwelcome.cpp" line="99"/>
        <location filename="../mxwelcome.cpp" line="111"/>
        <source>MX Welcome</source>
        <translation>MX Welkom</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="70"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Welcome to MX Linux, a fast, friendly, and stable OS loaded with amazing tools and supported by a great community. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Welkom bij MX Linux, een snelle, vriendelijke en stabiele OS die vol zit met verbazingwekkende gereedschappen en ondersteund wordt door een geweldige gemeenschap.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="113"/>
        <source>Popular Apps</source>
        <translation>Populaire Apps</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="203"/>
        <source>Forums</source>
        <translation>Forums</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="280"/>
        <source>Videos</source>
        <translation>Video&apos;s</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="377"/>
        <source>Contribute</source>
        <translation>Bijdragen</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="422"/>
        <source>Tweak (Panel, etc...)</source>
        <translation>Tweak (Paneel, etc...)</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="486"/>
        <source>Tools</source>
        <translation>Gereedschap</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="512"/>
        <source>Codecs</source>
        <translation>Codecs</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="544"/>
        <source>Wiki</source>
        <translation>Wiki</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="576"/>
        <source>Users Manual</source>
        <translation>Gebruikershandleiding</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="608"/>
        <source>FAQ</source>
        <translation>VGV</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="641"/>
        <source>Show this dialog at start up</source>
        <translation>Laat deze dialoog bij het opstarten zien</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="706"/>
        <source>About this application</source>
        <translation>Over deze toepassing</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="709"/>
        <source>About...</source>
        <translation>Over...</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="716"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="770"/>
        <source>Quit application</source>
        <translation>Verlaat de applicatie</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="773"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="780"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="57"/>
        <source>Default username:  &lt;b&gt;demo&lt;/b&gt; &lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Default demo password:  &lt;b&gt;demo&lt;/b&gt;</source>
        <translation>Standaard gebruikersnaam:  &lt;b&gt;demo&lt;/b&gt; &lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Standaard demo wachtwoord:  &lt;b&gt;demo&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="58"/>
        <source>&lt;b&gt;Root&lt;/b&gt; Password:  &lt;b&gt;root&lt;/b&gt;&lt;/p&gt; </source>
        <translation>&lt;b&gt;Root&lt;/b&gt; Wachtwoord:  &lt;b&gt;root&lt;/b&gt;&lt;/p&gt; </translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="98"/>
        <source>About MX Welcome</source>
        <translation>Over MX Welkom</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="99"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="100"/>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation>Programma om een welkomstscherm te laten zien in MX Linux</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="102"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="103"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="104"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="105"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="121"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
</context>
</TS>
